@@ -17,7 +17,6 @@
 #include "k9lvitemimport.h"
 #include <tdelocale.h>
 #include "k9menuedit.h"
-#include "k9haldevice.h"
 #include "k9config.h"
 #include "k9burndvd.h"
 #include <tqdir.h>
@@ -44,7 +43,7 @@ k9Import::~k9Import() {}
 void k9Import::init() {
     m_root=new TQListViewItem(lvDVD,i18n("Root Menu"));
     m_root->setOpen(true);
-    m_root->setPixmap(0,SmallIcon("media-optical-dvd"));
+    m_root->setPixmap(0,SmallIcon("media-optical-dvd-unmounted"));
     emit aviFileSelected(NULL);
 
     connect(drives,TQT_SIGNAL(deviceAdded( k9CdDrive*)),this,TQT_SLOT(deviceAdded( k9CdDrive* )));
@@ -80,12 +79,6 @@ void k9Import::deviceRemoved(k9CdDrive *_drive) {
 }
 
 void k9Import::addDrive(k9CdDrive *drive) {
-#ifdef HAVE_HAL
-    if (drive->getDevice()!=NULL) {
-        k9HalDevice *dev=drive->getDevice();
-        connect(dev,TQT_SIGNAL(volumeChanged( const TQString &,const TQString &)),this,TQT_SLOT(volumeChanged(const TQString&,const TQString&)));
-    }
-#endif
     if (drive->canWriteDVD) {
         cbOutputDev->insertItem(drive->name+ "  ("+drive->device+")",-1);
         recorderList.append(drive);
