@@ -12,8 +12,8 @@
 #include "k9importfiles.h"
 #include "k9import.h"
 #include "k9newtitle.h"
-#include "klocale.h"
-#include "kapplication.h"
+#include "tdelocale.h"
+#include "tdeapplication.h"
 #include "k9chapteredit.h"
 #include "k9avifile.h"
 #include "k9menuedit.h"
