@@ -15,9 +15,9 @@
 #include "k9common.h"
 
 #include <tqobject.h>
-#include <kmdidefines.h>
-#include <kmdichildarea.h>
-#include <kmdimainfrm.h>
+#include <tdemdidefines.h>
+#include <tdemdichildarea.h>
+#include <tdemdimainfrm.h>
 
 /**
 	@author Jean-Michel PETIT <k9copy@free.fr>
@@ -28,7 +28,7 @@ class k9NewTitle;
 class k9ImportFiles : public KMdiMainFrm
 {
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
     k9ImportFiles(TQWidget *parent = 0, const char *name = 0);
 
