@@ -18,18 +18,13 @@
 #include <tqstring.h>
 #include <tqstringlist.h>
 #include <tqvaluelist.h>
-#ifndef HAVE_HAL
 #include <k3bdevice.h>
 #include <k3bdevicemanager.h>
-#endif
 
 
 /**
   *@author 
   */
-class k9HalDevice;
-class k9HalConnection;
-
 class k9CdDrive : public TQObject {
     Q_OBJECT
   
@@ -46,16 +41,8 @@ public:
     void setWriteSpeeds(const TQValueList< int >& _value);
     TQValueList< int > getWriteSpeeds() const;
 
-    #ifdef HAVE_HAL
-    void setDevice(k9HalDevice* _value) { m_Device = _value;}
-	
-    k9HalDevice* getDevice()  { return m_Device;}
-    #endif
 private:
    TQValueList <int> writeSpeeds;
-   #ifdef HAVE_HAL
-   k9HalDevice *m_Device;
-   #endif
 };
 
 class k9CdDrives : public TQObject  {
@@ -70,19 +57,11 @@ public:
     k9CdDrive * getDrive(int num);
     void eject(const TQString & device);
     void scanDrives();
-public slots:
-   void deviceAdded(k9HalDevice *device);
-   void deviceRemoved(k9HalDevice *device);
 signals:
     void deviceAdded(k9CdDrive *drive);
     void deviceRemoved(k9CdDrive *drive);
 private: // Private methods
-    #ifdef HAVE_HAL
-    k9HalConnection *m_connection;
-    void addDrive(k9HalDevice *_device);
-    #else
     K3bDevice::DeviceManager *m_devMgr;
-    #endif
     void readConfig();
     TQPtrList <k9CdDrive> drives;
 };
