@@ -31,7 +31,6 @@
 #include "k9langselect.h"
 #include "k9config.h"
 #include "k9updatefactor.h"
-#include "k9haldevice.h"
 #include "k9titleencopt.h"
 #include <tdeselect.h>
 #include <kcombobox.h>
@@ -540,29 +539,12 @@ void k9Main::Open()
   closeDVD();
   TQString sDevice=getDevice(cbInputDev);
   
-  TQString sVolName="";  
-  //if no dvd label, try to get it from hal
-  for (k9CdDrive *drive=driveList.first();drive;drive=driveList.next()) {
-  #ifdef HAVE_HAL
-	if (drive->getDevice() != NULL) {
-		if (drive->getDevice()->mountPoint()==sDevice) {
-			sVolName=drive->getDevice()->getVolumeName();
-			sDevice=drive->device;
-			break;
-		}
-	}
-#endif
-  }     	
- 
   dvd->scandvd(sDevice,m_quickScan);
   if (dvd->geterror())
   {
     KMessageBox::error( this, dvd->geterrMsg(), i18n("Open DVD"));
     return;
   }
-  if (dvd->getDVDTitle()==i18n("unknown") && sVolName!="") {
-     dvd->setDVDTitle( sVolName);
-  }
  
   listView1->clear();
   items.clear();
@@ -576,7 +558,7 @@ void k9Main::Open()
   root->setRenameEnabled(0,true);
   root->obj=NULL;
   root->streamType=NONE;
-  root->setPixmap(0,SmallIcon("media-optical-dvd"));
+  root->setPixmap(0,SmallIcon("media-optical-dvd-unmounted"));
 
   for (i=0;i<dvd->gettitlesetCount();i++)
   {
@@ -1265,12 +1247,6 @@ void k9Main::deviceRemoved(k9CdDrive *_drive) {
 }
 
 void k9Main::addDrive(k9CdDrive *drive) {
-    #ifdef HAVE_HAL
-    if (drive->getDevice()!=NULL) {
-        k9HalDevice *dev=drive->getDevice();
-        connect(dev,TQT_SIGNAL(volumeChanged( const TQString &,const TQString &)),this,TQT_SLOT(volumeChanged(const TQString&,const TQString&)));
-    }
-    #endif
     if (drive->canReadDVD)
     {
       TQString c(drive->name + "  ("+drive->device+")");
