@@ -13,7 +13,7 @@
 #define K9SETTINGS_H
 
 #include "k9common.h"
-#include "kconfigdlg.h"
+#include "tdeconfigdlg.h"
 #include "k9prefdvd.h"
 #include "k9prefmpeg4.h"
 #include "k9prefmencoder.h"
@@ -26,7 +26,7 @@
 */
 class k9settings:public KDialogBase{
 Q_OBJECT
-  TQ_OBJECT
+  
 public:
     k9settings(TQWidget *parent,const TQString &caption);
 
